@@ -1,7 +1,7 @@
 /*
  *   xmmix - Motif(tm) Audio Mixer
  *
- *   Copyright (C) 1995  Ti Kan
+ *   Copyright (C) 1994-1996  Ti Kan
  *   E-mail: ti@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  */
 #ifndef LINT
-static char *_mixer_c_ident_ = "@(#)mixer.c	2.15 95/05/13";
+static char *_mixer_c_ident_ = "@(#)mixer.c	3.5 96/11/07";
 #endif
 
 #include "appenv.h"
@@ -29,6 +29,16 @@ static char *_mixer_c_ident_ = "@(#)mixer.c	2.15 95/05/13";
 #include "mixer.h"
 
 
+#if defined(SOUND_MIXER_LOUD) && defined(SOUND_MIXER_MUTE) && \
+    defined(SOUND_MIXER_ENHANCE)
+#if SOUND_MIXER_LOUD == SOUND_MIXER_MUTE
+/* HACK for new sound drivers */
+#undef SOUND_MIXER_LOUD
+#undef SOUND_MIXER_MUTE
+#undef SOUND_MIXER_ENHANCE
+#endif
+#endif
+
 /* Ioctl data direction flags */
 #define IOC_DATA_NONE	0
 #define IOC_DATA_IN	1
@@ -223,12 +233,20 @@ mx_queryhw(widgets_t *m)
 			do_ioctl(MIXER_READ(i), &level, iocstr, IOC_DATA_IN);
 
 			switch (i) {
+
+#ifdef SOUND_MIXER_MUTE
 			case SOUND_MIXER_MUTE:
 				ctlinfo.mute = (level != 0);
 				break;
+#endif	/* SOUND_MIXER_MUTE */
+
+#ifdef SOUND_MIXER_LOUD
 			case SOUND_MIXER_LOUD:
 				ctlinfo.loudness = (level != 0);
 				break;
+#endif	/* SOUND_MIXER_LOUD */
+
+#ifdef SOUND_MIXER_ENHANCE
 			case SOUND_MIXER_ENHANCE:
 				/* Hack: The enhance values are hard wired. */
 				switch (level) {
@@ -247,6 +265,8 @@ mx_queryhw(widgets_t *m)
 					break;
 				}
 				break;
+#endif	/* SOUND_MIXER_ENHANCE */
+
 			default:
 				/* Unsupported feature: ignore */
 				break;
@@ -500,20 +520,30 @@ mx_readfile(char *path)
 		}
 #ifdef SOUND_ONOFF_MAX
 		else if (sscanf(p+1, "%d\n", &val1) == 1) {
+
+#ifdef SOUND_MIXER_MUTE
 			if (strcmp(buf, "mute") == 0 &&
 			    ctlinfo.devmask & (1 << SOUND_MIXER_MUTE)) {
 				ctlinfo.mute = (bool_t) (val1 > 0);
 			}
-			else if (strcmp(buf, "enhance") == 0 &&
+#endif	/* SOUND_MIXER_MUTE */
+
+#ifdef SOUND_MIXER_ENHANCE
+			if (strcmp(buf, "enhance") == 0 &&
 				 ctlinfo.devmask & (1 << SOUND_MIXER_ENHANCE)) {
 				ctlinfo.enhance = val1;
 			}
-			else if (strcmp(buf, "loudness") == 0 &&
+#endif	/* SOUND_MIXER_ENHANCE */
+
+#ifdef SOUND_MIXER_LOUD
+			if (strcmp(buf, "loudness") == 0 &&
 				 ctlinfo.devmask & (1 << SOUND_MIXER_LOUD)) {
 				ctlinfo.loudness = (bool_t) (val1 > 0);
 			}
+#endif	/* SOUND_MIXER_LOUD */
+
 		}
-#endif
+#endif	/* SOUND_ONOFF_MAX */
 	}
 
 	fclose(fp);
@@ -553,7 +583,7 @@ mx_writefile(char *path)
 
 	/* Write first two lines of mixer settings file */
 	fprintf(fp, "# xmmix %s Mixer Settings File\n", VERSION);
-	fprintf(fp, "# Copyright (C) 1995 Ti Kan\n#\n");
+	fprintf(fp, "# Copyright (C) 1994-1996 Ti Kan\n#\n");
 
 	/* Write all control settings */
 	for (i = 0; i < MAXDEVS; i++) {
@@ -654,7 +684,7 @@ mx_init_drv(void)
 			fprintf(errfp, "%s: %s: %s\n",
 				PROGNAME,
 				"Cannot open /dev/sndstat",
-				"assuming pre-3.0 VoxWare driver.");
+				"assuming pre-3.0 sound driver.");
 			maxdevs = MAXDEVS_V2;
 		}
 		return;
@@ -665,7 +695,7 @@ mx_init_drv(void)
 			fprintf(errfp, "%s: %s: %s\n",
 				PROGNAME,
 				"Cannot read /dev/sndstat",
-				"assuming pre-3.0 VoxWare driver.");
+				"assuming pre-3.0 sound driver.");
 			maxdevs = MAXDEVS_V2;
 		}
 		fclose(fp);
@@ -677,31 +707,36 @@ mx_init_drv(void)
 	/* Eat newline */
 	tmpbuf[strlen(tmpbuf) - 1] = '\0';
 
-	/* Skip forward to the first colon character */
-	for (p = tmpbuf; *p != '\0' && *p != ':'; p++)
-		;
+	p = tmpbuf;
+	if (strncmp(p, "Sound Driver", 12) == 0) {
+		/* Old style output:
+		 * Skip forward to the first colon character
+		 */
+		for (; *p != '\0' && *p != ':'; p++)
+			;
 
-	if (*p != ':') {
-		if (!app_data.demo) {
-			fprintf(errfp, "%s: %s: %s\n",
-				PROGNAME,
-				"Cannot parse info from /dev/sndstat",
-				"assuming pre-3.0 VoxWare driver.");
-			maxdevs = MAXDEVS_V2;
+		if (*p != ':') {
+			if (!app_data.demo) {
+				fprintf(errfp, "%s: %s: %s\n",
+					PROGNAME,
+					"Cannot parse info from /dev/sndstat",
+					"assuming pre-3.0 sound driver.");
+				maxdevs = MAXDEVS_V2;
+			}
+			strcpy(drv_ver, tmpbuf);
+			return;
 		}
-		strcpy(drv_ver, tmpbuf);
-		return;
-	}
 
-	/* Skip blanks */
-	p++;
-	while (*p == ' ' || *p == '\t')
+		/* Skip blanks */
 		p++;
+		while (*p == ' ' || *p == '\t')
+			p++;
+	}
 
 	strcpy(drv_ver, p);
 
-	if (!app_data.demo && *p < '3')
-		/* Running on VoxWare 2.x: set max devices accordingly */
+	if (!app_data.demo && *p >= '0' && *p < '3')
+		/* Running on old sound driver: set max devices accordingly */
 		maxdevs = MAXDEVS_V2;
 
 	if (app_data.debug) {
@@ -825,24 +860,34 @@ mx_init_hw(widgets_t *m)
 		curmask = (1 << i);
 
 		switch (i) {
+
+#ifdef SOUND_MIXER_MUTE
 		case SOUND_MIXER_MUTE:
 			if (curmask & ctlinfo.devmask)
 				m->mute_supp = TRUE;
 			else
 				m->mute_supp = FALSE;
 			break;
+#endif	/* SOUND_MIXER_MUTE */
+
+#ifdef SOUND_MIXER_LOUD
 		case SOUND_MIXER_LOUD:
 			if (curmask & ctlinfo.devmask)
 				m->loud_supp = TRUE;
 			else
 				m->loud_supp = FALSE;
 			break;
+#endif	/* SOUND_MIXER_LOUD */
+
+#ifdef SOUND_MIXER_ENHANCE
 		case SOUND_MIXER_ENHANCE:
 			if (curmask & ctlinfo.devmask)
 				m->enh_supp = TRUE;
 			else
 				m->enh_supp = FALSE;
 			break;
+#endif	/* SOUND_MIXER_ENHANCE */
+
 		default:
 			/* Unsupported feature: ignore */
 			break;
@@ -1108,7 +1153,7 @@ mx_mute_btn(Widget w, XtPointer client_data, XtPointer call_data)
 
 	level = (int) p->set;
 
-#ifdef SOUND_MIXER_WRITE_MUTE
+#ifdef SOUND_MIXER_MUTE
 	do_ioctl(
 		SOUND_MIXER_WRITE_MUTE,
 		&level,
@@ -1139,7 +1184,7 @@ mx_loud_btn(Widget w, XtPointer client_data, XtPointer call_data)
 
 	level = (int) p->set;
 
-#ifdef SOUND_MIXER_WRITE_LOUD
+#ifdef SOUND_MIXER_LOUD
 	do_ioctl(
 		SOUND_MIXER_WRITE_LOUD,
 		&level,
@@ -1185,7 +1230,7 @@ mx_enhance_btn(Widget w, XtPointer client_data, XtPointer call_data)
 		return;
 	}
 
-#ifdef SOUND_MIXER_WRITE_ENHANCE
+#ifdef SOUND_MIXER_ENHANCE
 	do_ioctl(
 		SOUND_MIXER_WRITE_ENHANCE,
 		&level,
@@ -1357,13 +1402,13 @@ mx_about(Widget w, XtPointer client_data, XtPointer call_data)
 		VERSION_EXT,
 		PATCHLEVEL,
 		"Motif(tm) Audio Mixer",
-		"Copyright (C) 1995  Ti Kan",
+		"Copyright (C) 1994-1996  Ti Kan",
 		"E-mail: ti@amb.org");
 
 	xs_desc = XmStringCreateLtoR(txt, CHSET2);
 
 	sprintf(txt, "%s %d\n\nDevice: %s\nDriver: %s\n\n%s\n%s\n",
-		"Compiled with VoxWare soundcard.h version",
+		"Compiled with Unix Sound System soundcard.h version",
 		SOUND_VERSION,
 		app_data.demo ?
 		"DEMO MODE - does not operate sound hardware" :
