@@ -1,7 +1,7 @@
 /*
  *   xmmix - Motif(tm) Audio Mixer
  *
- *   Copyright (C) 1995  Ti Kan
+ *   Copyright (C) 1994-1996  Ti Kan
  *   E-mail: ti@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  */
 #ifndef LINT
-static char *_widget_c_ident_ = "@(#)widget.c	2.5 95/05/12";
+static char *_widget_c_ident_ = "@(#)widget.c	3.3 96/07/14";
 #endif
 
 #include "appenv.h"
@@ -493,50 +493,29 @@ bm_to_px(Widget w, void *bits, int width, int height, int depth)
 	Display		*display = XtDisplay(w);
 	Window		window	 = XtWindow(w);
 	int		screen	 = DefaultScreen(display);
-	GC		pixmap_gc;
-	XGCValues	val;
-	Pixmap		tmp_bitmap;
-	static Pixmap	ret_pixmap;
-
-	tmp_bitmap = XCreateBitmapFromData(
-		display, window, (char *) bits, width, height
-	);
-	if (tmp_bitmap == (Pixmap) NULL)
-		return ((Pixmap) NULL);
-
-	if (depth == 1) {
-		ret_pixmap = tmp_bitmap;
-		return (ret_pixmap);
-	}
-
-	/* Create pixmap with depth */
-	ret_pixmap = XCreatePixmap(display, window, width, height, depth);
-	if (ret_pixmap == (Pixmap) NULL)
-		return ((Pixmap) NULL);
+	Pixmap		ret_pixmap;
+	Pixel		fg,
+			bg;
 
 	/* Allocate colors for pixmap if on color screen */
-	if (DisplayCells(display, screen) > 2) {
-		/* Get pixmap color configuration */
+	if (DisplayCells(display, screen) > 2 && depth > 1) {
 		XtVaGetValues(w,
-			XmNforeground, &val.foreground,
-			XmNbackground, &val.background,
+			XmNforeground, &fg,
+			XmNbackground, &bg,
 			NULL
 		);
-
-		/* Create GC for pixmap */
-		pixmap_gc = XCreateGC(
-			display, window, GCForeground | GCBackground, &val
-		);
 	}
-	else
-		pixmap_gc = DefaultGC(display, screen);
-		
-	/* Copy bitmap into pixmap */
-	XCopyPlane(display, tmp_bitmap, ret_pixmap, pixmap_gc,
-		   0, 0, width, height, 0, 0, 1);
+	else {
+		fg = BlackPixel(display, screen);
+		bg = WhitePixel(display, screen);
+	}
 
-	/* No need for the bitmap any more, so free it */
-	XFreePixmap(display, tmp_bitmap);
+	ret_pixmap = XCreatePixmapFromBitmapData(
+		display, window, (char *) bits, width, height, fg, bg, depth
+	);
+
+	if (ret_pixmap == (Pixmap) NULL)
+		return ((Pixmap) NULL);
 
 	return (ret_pixmap);
 }
